==> nextcloud-23.0.3.tgz: nextcloud/apps/weather_status/l10n/de_DE.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Unbekannte Adresse",
    "No result." : "Kein Ergebnis.",
    "Malformed JSON data." : "Fehlerhafte JSON-Daten.",
    "Error" : "Fehler",
    "Weather status" : "Wetter Status",
    "Weather status in your dashboard" : "Wetter Status in deinem Dashboard",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Wetterstatus wird in die Dashboard-App integriert.\nDie Position des Benutzers kann automatisch bestimmt oder manuell definiert werden. Anschließend wird eine 6-Stunden-Vorhersage angezeigt.\nDieser Status kann auch an anderen Stellen wie in der Kalender-App integriert werden.",
    "Detect location" : "Ort erkennen",
    "Set custom address" : "Benutzerdefinierte Adresse festlegen",
    "Favorites" : "Favoriten",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} Klarer Himmel später am Tag",
    "{temperature} {unit} clear sky" : "{temperature} {unit} Klarer Himmel",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} Bewölkt später am Tag",
    "{temperature} {unit} cloudy" : "{temperature} {unit} Bewölkt",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} Schönes Wetter später am Tag",
    "{temperature} {unit} fair weather" : "{temperature} {unit} Schönes Wetter",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} Teilweise bewölkt später am Tag",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} Teilweise bewölkt",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} Neblig später am Tag",
    "{temperature} {unit} foggy" : "{temperature} {unit} Neblig",
    "{temperature} {unit} light rain later today" : "{temperature} {unit} Leichter Regen später am Tag",
    "{temperature} {unit} light rain" : "{temperature} {unit} Leichter Regen",
    "{temperature} {unit} rain later today" : "{temperature} {unit} Regen später am Tag",
    "{temperature} {unit} rain" : "{temperature} {unit} Regen",
    "{temperature} {unit} heavy rain later today" : "{temperature} {unit} Starker Regen später am Tag",
    "{temperature} {unit} heavy rain" : "{temperature} {unit} Starker Regen",
    "{temperature} {unit} rain showers later today" : "{temperature} {unit} Regenschauer später am Tag",
    "{temperature} {unit} rain showers" : "{temperature} {unit} Regenschauer",
    "{temperature} {unit} light rain showers later today" : "{temperature} {unit} Leichte Regenschauer später am Tag",
    "{temperature} {unit} light rain showers" : "{temperature} {unit} Leichte Regenschauer",
    "{temperature} {unit} heavy rain showers later today" : "{temperature} {unit} Starke Regenschauer später am Tag",
    "{temperature} {unit} heavy rain showers" : "{temperature} {unit} Starke Regenschauer",
    "More weather for {adr}" : "Mehr Wetter für {adr}",
    "Loading weather" : "Lade Wetter",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Add as favorite" : "Als Favorit hinzufügen",
    "You are not logged in." : "Sie sind nicht angemeldet.",
    "There was an error getting the weather status information." : "Beim Abrufen der Wetterstatusinformationen ist ein Fehler aufgetreten.",
    "No weather information found" : "Keine Wetterinformationen gefunden",
    "Location not found" : "Ort nicht gefunden",
    "There was an error setting the location address." : "Beim Festlegen der Standortadresse ist ein Fehler aufgetreten.",
    "There was an error setting the location." : "Beim Festlegen des Standortes ist ein Fehler aufgetreten.",
    "There was an error saving the mode." : "Beim Festlegen des Modus ist ein Fehler aufgetreten.",
    "There was an error using personal address." : "Bei der Verwendung der persönlichen Adresse ist ein Fehler aufgetreten.",
    "Set location for weather" : "Stelle Standort für Wetterinformation ein.",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Klarer Himmel um {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Bewölkt um {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Heiterer Tag um {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Heitere Nacht um {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Teilweise bewölkt um {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Nebelig um {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Leichter Regen um {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Regen um {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Starker Regen um {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Regenschauer um {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Leichte Regenschauer um {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Starke Regenschauer um {time}"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.9.tgz: nextcloud/apps/weather_status/l10n/de_DE.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Unbekannte Adresse",
    "No result." : "Kein Ergebnis.",
    "Malformed JSON data." : "Fehlerhafte JSON-Daten.",
    "Error" : "Fehler",
    "Weather status" : "Wetter Status",
    "Weather status in your dashboard" : "Wetter Status in deinem Dashboard",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Wetterstatus wird in die Dashboard-App integriert.\nDie Position des Benutzers kann automatisch bestimmt oder manuell definiert werden. Anschließend wird eine 6-Stunden-Vorhersage angezeigt.\nDieser Status kann auch an anderen Stellen wie in der Kalender-App integriert werden.",
    "Detect location" : "Ort erkennen",
    "Set custom address" : "Benutzerdefinierte Adresse festlegen",
    "Favorites" : "Favoriten",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} Klarer Himmel später am Tag",
    "{temperature} {unit} clear sky" : "{temperature} {unit} Klarer Himmel",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} Bewölkt später am Tag",
    "{temperature} {unit} cloudy" : "{temperature} {unit} Bewölkt",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} Schönes Wetter später am Tag",
    "{temperature} {unit} fair weather" : "{temperature} {unit} Schönes Wetter",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} Teilweise bewölkt später am Tag",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} Teilweise bewölkt",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} Neblig später am Tag",
    "{temperature} {unit} foggy" : "{temperature} {unit} Neblig",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} Leichter Regen später am Tag",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} Leichter Regen",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} Regen später am Tag",
    "{temperature} {unit} rainfall" : "{temperature} {unit} Regen",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} Starker Regen später am Tag",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} Starker Regen",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} Regenschauer später am Tag",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} Regenschauer",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} Leichte Regenschauer später am Tag",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} Leichte Regenschauer",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} Starke Regenschauer später am Tag",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} Starke Regenschauer",
    "More weather for {adr}" : "Mehr Wetter für {adr}",
    "Loading weather" : "Lade Wetter",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Add as favorite" : "Als Favorit hinzufügen",
    "You are not logged in." : "Sie sind nicht angemeldet.",
    "There was an error getting the weather status information." : "Beim Abrufen der Wetterstatusinformationen ist ein Fehler aufgetreten.",
    "No weather information found" : "Keine Wetterinformationen gefunden",
    "Location not found" : "Ort nicht gefunden",
    "There was an error setting the location address." : "Beim Festlegen der Standortadresse ist ein Fehler aufgetreten.",
    "There was an error setting the location." : "Beim Festlegen des Standortes ist ein Fehler aufgetreten.",
    "There was an error saving the mode." : "Beim Festlegen des Modus ist ein Fehler aufgetreten.",
    "There was an error using personal address." : "Bei der Verwendung der persönlichen Adresse ist ein Fehler aufgetreten.",
    "Set location for weather" : "Stelle Standort für Wetterinformation ein.",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Klarer Himmel um {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Bewölkt um {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Heiterer Tag um {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Heitere Nacht um {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Teilweise bewölkt um {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Nebelig um {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Leichter Regen um {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Regen um {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Starker Regen um {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Regenschauer um {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Leichte Regenschauer um {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Starke Regenschauer um {time}"
},
"nplurals=2; plural=(n != 1);");
